@@ -2,10 +2,10 @@ from PIL import Image
 import inspect
 import requests
 
-DRAWING_CHARS = ['#', '#', '#', '#', '#', '#', '#', ';', ':', ',', '.']
+DRAWING_CHARS = ['#', '#', '#', '#', '#', '#', '#', ' ', ' ', ' ', ' ']
 
 
-def resize_image(image,new_width=50):
+def resize_image(image,new_width=40):
     width,height = image.size
     ratio = height//width
     new_height = int(new_width*ratio*0.80)
@@ -18,7 +18,7 @@ def pixels_to_ascii(image):
     return(characters)
     
 
-def main(new_width=50):
+def main(new_width=40):
     path =  inspect.getfile(requests)[:-20]+"m1key/profile.jpeg"
     image = Image.open(path)
     new_image = pixels_to_ascii((resize_image(image)).convert("L"))
@@ -26,4 +26,5 @@ def main(new_width=50):
     ascii_image = "\n".join(new_image[i:(i+new_width)] for i in range(0,pixel_count,new_width))
     print(ascii_image)
     print()
-    print("""Hello, it's Mithilesh Tiwari , aka m1key. Welcome to m1key world.""")
\ No newline at end of file
+    print("""Hello, it's Mithilesh Tiwari , aka m1key. Welcome to m1key world.
+Run m1key -h to know what you can do...""")
\ No newline at end of file
